@@ -8,8 +8,9 @@ use warnings;
 sub save_on_exit {
 
 	# checking settings if i should save or quit without question
-	if    ($Kephra::config{file}{save}{b4_quit} eq '0') {                      return}
-	elsif ($Kephra::config{file}{save}{b4_quit} eq '1') {&Kephra::File::save_all; return}
+	my $save = Kephra::API::settings()->{file}{save}{b4_quit};
+	if    ($save eq '0') {                         return}
+	elsif ($save eq '1') {&Kephra::File::save_all; return}
 
 	# count unsaved dacuments?
 	my $unsaved_docs = 0;
@@ -35,7 +36,7 @@ sub save_on_exit {
 		my ( $x_size,     $y_size );
 		my ( $file_name,  $check_label );
 		my $align_lc = &Wx::wxLEFT | &Wx::wxALIGN_CENTER_VERTICAL;
-		my $l10n = Kephra::Config::Localisation::strings->{dialog}{general};
+		my $l10n = Kephra::Config::Localisation::strings()->{dialog}{general};
 
 		# generating checkbox list of unsaved files
 		for ( @{ Kephra::Document::Data::all_nr() } ) {
