@@ -17,6 +17,7 @@ sub set_absolete { $menu{$_[0]}{absolete} = 1     }
 sub not_absolete { $menu{$_[0]}{absolete} = 0     }
 sub is_absolete  { $menu{$_[0]}{absolete}         }
 sub set_update   { $menu{$_[0]}{update} =  $_[1] if ref $_[1] eq 'CODE' }
+sub get_update   { $menu{$_[0]}{update} }
 sub no_update    { delete $menu{$_[0]}{update} if stored($_[0]) }
 sub add_onopen_check {
 	return until ref $_[2] eq 'CODE';
@@ -32,8 +33,8 @@ sub ready          { # make menu ready for display
 	my $id = shift;
 	if ( stored($id) ){
 		my $menu = _data($id);
-		if ($menu->{absolete} and $menu->{update})
-			{ $menu->{absolete} = 0 if $menu->{update}() }
+		if ($menu->{absolete} and $menu->{update}) {
+			 $menu->{absolete} = 0 if $menu->{update}() }
 		if (ref $menu->{onopen} eq 'HASH')
 			{ $_->() for values %{$menu->{onopen}} }
 		_ref($id);
@@ -46,6 +47,7 @@ sub create_dynamic { # create on runtime changeable menus
 
 	if ($menu_name eq '&insert_templates') {
 
+		set_absolete($menu_id);
 		set_update($menu_id, sub {
 			my $cfg = Kephra::API::settings()->{file}{templates}; 
 			my $file = Kephra::Config::filepath($cfg->{directory}, $cfg->{file});
@@ -72,12 +74,13 @@ sub create_dynamic { # create on runtime changeable menus
 					push @menu_data, \%item; 
 					eval_data($menu_id, \@menu_data);
 				}
+				return 1;
 			}
 		});
-		set_absolete($menu_id);
 
 	} elsif ($menu_name eq '&file_history'){
 
+		set_absolete($menu_id);
 		set_update($menu_id, sub {
 			my @menu_data = @{assemble_data_from_def
 				( ['item file-session-history-open-all', undef] )};
@@ -95,8 +98,9 @@ sub create_dynamic { # create on runtime changeable menus
 				}
 			}
 			eval_data($menu_id, \@menu_data);
+			return Kephra::File::History::had_init() ? 1 : 0;
+			1; # it was successful
 		});
-		set_absolete($menu_id);
 
 		Kephra::EventTable::add_call (
 			'document.list', 'menu_'.$menu_id, sub {
@@ -143,6 +147,30 @@ sub create_static  { # create solid, not on runtime changeable menus
 	eval_data($menu_id, assemble_data_from_def($menu_def));
 }
 
+sub create_menubar {
+	#my $menubar    = Wx::MenuBar->new();
+	#my $m18n = Kephra::Config::Localisation::strings()->{app}{menu};
+	#my ($pos, $menu_name);
+	#for my $menu_def ( @$menubar_def ){
+		#for my $menu_id (keys %$menu_def){
+			# removing the menu command if there is one
+			#$pos = index $menu_id, ' ';
+			#if ($pos > -1){
+				#if ('menu' eq substr $menu_id, 0, $pos ){
+					#$menu_name = substr ($menu_id, $pos+1);
+				# ignoring menu structure when command other that menu or blank
+				#} else { next }
+			#} else { 
+				#$menu_name = $menu_id;
+			#}
+			#$menubar->Append(
+				#Kephra::Menu::create_static( $menu_name, $menu_def->{$menu_id}),
+				#$m18n->{label}{$menu_name}
+			#);
+		#}
+	#}
+}
+
 # create menu data structures (MDS) from menu skeleton definitions (command list)
 sub assemble_data_from_def {
 	my $menu_def = shift;
@@ -233,13 +261,15 @@ sub eval_data { # eval menu data structures (MDS) to wxMenus
 	for my $item_data (@$menu_data){
 		if (not $item_data->{type} or $item_data->{type} eq 'separator'){
 			$menu->AppendSeparator;
-		} elsif ($item_data->{type} eq 'menu'){
+		}
+		elsif ($item_data->{type} eq 'menu'){
 			my $submenu = ref $item_data->{data} eq 'ARRAY'
 				? eval_data( $item_data->{id}, $item_data->{data} )
 				: ready( $item_data->{id} );
 			$item_data->{help} = '' unless defined $item_data->{help};
-			my @params = ( $menu, $item_id++, 
-				$item_data->{label}, $item_data->{help}, &Wx::wxITEM_NORMAL );
+			my @params = ( $menu, $item_id++, $item_data->{label},$item_data->{help},
+				&Wx::wxITEM_NORMAL
+			);
 			push @params, $submenu if is ($submenu);
 			my $menu_item = Wx::MenuItem->new( @params );
 			if (defined $item_data->{icon}) {
@@ -252,7 +282,8 @@ sub eval_data { # eval menu data structures (MDS) to wxMenus
 			#	Kephra::App::StatusBar::info_msg( $item_data->{help} )
 			#});
 			$menu->Append($menu_item);
-		} else {
+		} 
+		else { # create normal items
 			if    ($item_data->{type} eq 'checkitem'){$kind = &Wx::wxITEM_CHECK}
 			elsif ($item_data->{type} eq 'radioitem'){$kind = &Wx::wxITEM_RADIO}
 			elsif ($item_data->{type} eq 'item')     {$kind = &Wx::wxITEM_NORMAL}
@@ -288,6 +319,7 @@ sub eval_data { # eval menu data structures (MDS) to wxMenus
 	}
 
 	Kephra::EventTable::add_call('menu.open', 'menu_'.$menu, sub {ready($menu_id)});
+#print "did  $menu_id \n";
 	_ref($menu_id, $menu);
 	return $menu;
 }
